@@ -1,7 +1,7 @@
 from fab_deploy.deploy import *
 from fab_deploy.virtualenv import pip, pip_install, pip_update
 from fab_deploy.django_commands import migrate, manage, syncdb, compress, test, coverage
-from fab_deploy.utils import run_as, update_env, inside_project, inside_virtualenv, delete_pyc
+from fab_deploy.utils import run_as, update_env, inside_project, inside_virtualenv, delete_pyc, print_env
 from fab_deploy.system import create_linux_account, ssh_add_key
 from fab_deploy.crontab import crontab_set, crontab_add, crontab_show, crontab_remove, crontab_update
 from fab_deploy.mysql import mysql_execute, mysql_install, mysql_create_db, mysqldump
