@@ -33,15 +33,13 @@ def deploy_project():
 
 def make_clone():
     """ Creates repository clone on remote server. """
-    with cd('src'):
+    run('mkdir -p '+ env.conf.SRC_DIR)
+    with cd(env.conf.SRC_DIR):
         with settings(warn_only=True):
-            run('mkdir %s' % env.conf['INSTANCE_NAME'])
-            with cd(env.conf['INSTANCE_NAME']):
-                vcs.init()
+            vcs.init()
     vcs.push()
-    with cd('src'):
-        with cd(env.conf['INSTANCE_NAME']):
-            vcs.up()
+    with cd(env.conf.SRC_DIR):
+        vcs.up()
     update_django_config(restart=False)
     vcs.configure()
 
