@@ -6,7 +6,11 @@ from fab_deploy.utils import inside_project
 
 @inside_project
 def manage(command):
-    """ Runs django management command. """
+    """ Runs django management command.
+    Example::
+
+        fab manage:createsuperuser
+    """
     run('python ./manage.py '+ command)
 
 def migrate(params='', do_backup=True):
@@ -28,7 +32,19 @@ def compress(params=''):
 
 @inside_project
 def test(what=''):
-    """ Runs 'runtests.sh' script from project root. """
+    """ Runs 'runtests.sh' script from project root.
+    Example runtests.sh content::
+
+        #!/bin/sh
+
+        default_tests='accounts forum firms blog'
+        if [ $# -eq 0 ]
+        then
+            ./manage.py test $default_tests --settings=test_settings
+        else
+            ./manage.py test $* --settings=test_settings
+        fi
+    """
     with settings(warn_only=True):
         run('./runtests.sh ' + what)
 
