@@ -1,9 +1,10 @@
 from datetime import datetime
 from fabric.api import *
-from fab_deploy.utils import run_as, inside_project
+from fab_deploy.utils import run_as, inside_project, supports_only
 from fab_deploy.system import aptitude_install
 
 @run_as('root')
+@supports_only('lenny, squeeze')
 def mysql_install():
     """ Installs mysql. """
     if _mysql_is_installed():
@@ -14,11 +15,17 @@ def mysql_install():
     # see http://serverfault.com/questions/19367/scripted-install-of-mysql-on-ubuntu
     aptitude_install('debconf-utils')
     passwd=env.conf['DB_PASSWORD']
-    defaults = """mysql-server-5.0\tmysql-server/root_password_again\tpassword\t%s
-mysql-server-5.0\tmysql-server/root_password\tpassword\t%s""" % (passwd, passwd,)
-    run("echo '%s' | debconf-set-selections" % defaults)
-    warn('\n=========\nThe password for mysql "root" user will be set to "%s"\n=========\n' % passwd)
 
+    mysql_versions = {'lenny': '5.0', 'squeeze': '5.1'}
+    version = mysql_versions[env.conf.OS]
+
+    debconf_defaults = [
+        "mysql-server-%s\tmysql-server/root_password_again\tpassword\t%s" % (version, passwd),
+        "mysql-server-%s\tmysql-server/root_password\tpassword\t%s" % (version, passwd),
+    ]
+    run("echo '%s' | debconf-set-selections" % "\n".join(debconf_defaults))
+
+    warn('\n=========\nThe password for mysql "root" user will be set to "%s"\n=========\n' % passwd)
     aptitude_install('mysql-server')
 
 def _mysql_is_installed():
