@@ -14,9 +14,9 @@ def prepare_server():
 @supports_only('lenny, squeeze')
 def install_common_software():
     """ Installs common system packages. """
-    to_install = [
+    common_packages = [
         'python', 'build-essential', 'python-dev', 'python-setuptools',
-        'python-profiler', 'libjpeg-dev', 'libmysqlclient-dev', 'zlib1g-dev',
+        'python-profiler', 'libjpeg-dev', 'zlib1g-dev',
         'libssl-dev', 'libcurl3-dev',
 
         'screen', 'locales-all', 'curl',
@@ -24,7 +24,12 @@ def install_common_software():
         'subversion',
     ]
 
-    aptitude_install(" ".join(to_install))
+    extra_packages = {
+        'lenny': ['libmysqlclient15-dev'],
+        'squeeze': ['libmysqlclient-dev'],
+    }
+
+    aptitude_install(" ".join(common_packages + extra_packages[env.conf.OS]))
 
     # git and mercurial are outdated in stable Debian Lenny and
     # don't work with some source repositories on github and bitbucket
