@@ -96,6 +96,7 @@ def update_env():
         SERVER_NAME = host,
         SERVER_ADMIN = 'example@example.com',
         OS = 'lenny',
+        VCS = 'hg',
 
         # these options shouldn't be set by user
         HOME_DIR = HOME_DIR,
@@ -106,6 +107,10 @@ def update_env():
     defaults.update(env.conf)
     env.conf = defaults
 
+    for vcs in ['hg', 'none']: # expand VCS name to full import path
+        if env.conf.VCS == vcs:
+            env.conf.VCS = 'fab_deploy.vcs.'+vcs
+
     if env.conf.OS not in SUPPORTED_SYSTEMS:
         abort('%s is not supported. Supported operating systems: %s' % (
             env.conf.OS, ', '.join(SUPPORTED_SYSTEMS)
